``marker`` can now be set to the string "none"
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
... to mean *no-marker*, consistently with other APIs which support the
lowercase version.  Using "none" is recommended over using "None", to avoid
confusion with the None object.
